==> mono_1.2.4.orig.tar.gz: mono-1.2.4/mcs/class/corlib/Microsoft.Win32.SafeHandles/SafeWaitHandle.cs <==
//
// Microsoft.Win32.SafeHandles.SafeWaitHandle
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//      Miguel de Icaza    <miguel@novell.com>
//
// Copyright (C) 2005, 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.IO;
using System.Threading;

namespace Microsoft.Win32.SafeHandles {

	public sealed class SafeWaitHandle : SafeHandleZeroOrMinusOneIsInvalid {
		public SafeWaitHandle (IntPtr preexistingHandle, bool ownsHandle) : base (ownsHandle)
		{
			SetHandle (preexistingHandle);
		}

		protected override bool ReleaseHandle ()
		{
			NativeEventCalls.CloseEvent_internal (DangerousGetHandle ());
			return true;
		}

	}
}

#endif

==> mono_1.2.6+dfsg.orig.tar.gz: mono-1.2.6+dfsg/mcs/class/corlib/Microsoft.Win32.SafeHandles/SafeWaitHandle.cs <==
//
// Microsoft.Win32.SafeHandles.SafeWaitHandle
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//      Miguel de Icaza    <miguel@novell.com>
//
// Copyright (C) 2005, 2006 Novell, Inc (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;
using System.IO;
using System.Threading;
using System.Runtime.ConstrainedExecution;

namespace Microsoft.Win32.SafeHandles {

	public sealed class SafeWaitHandle : SafeHandleZeroOrMinusOneIsInvalid {
		[ReliabilityContract (Consistency.WillNotCorruptState, Cer.MayFail)]
		public SafeWaitHandle (IntPtr preexistingHandle, bool ownsHandle) : base (ownsHandle)
		{
			SetHandle (preexistingHandle);
		}

		protected override bool ReleaseHandle ()
		{
			NativeEventCalls.CloseEvent_internal (handle);
			return true;
		}

	}
}

#endif
